from callback.Callback import Callback
from Timer import Timer
from matrix_wrapper import *
from callback.callbacks import TimerCallback
from callback.callbacks.HelpCallback import HelpCallback
from callback import callback_helper

class TimerCallback(Callback):
    ACTION_NAME = "timer"

    async def run(self, args: dict):
        timer_actions = args.get(Callback.NO_PARAM)

        if not timer_actions:
            await help()
            return
        
        timer_action = timer_actions.pop(0)
        if timer_action == Callback.GET_PARAM:
            message = """<h2>List Timers</h2>
<table>
    <tr>
        <th>Timer ID</th>
        <th>Message</th>
        <th>State</th>
        <th>Remaining time</th>
    </tr>
        """
            with Timer.timers_lock:
                for timer in Timer.timers:
                    timer_state = timer.get_state()
                    message += "<tr><td>{}</td><td>{}</td><td>{}</td><td>".format(timer.get_id(), timer.get_callback_message(), timer_state)

                    if timer_state == Timer.STATE_RUNNING:
                        message += str(timer.remaining())
                    message += "</td></tr>"
                message += "</table>"

            await send_html(message)

        elif timer_action == Callback.CREATE_PARAM:
            pre_command = "{} {}".format(Callback.TIMER_PARAM, Callback.CREATE_PARAM)
            callback_message = await callback_helper.get_single_param(args, Callback.TEXT_ARG, pre_command, required=False)
            duration = await callback_helper.get_single_param(args, Callback.DURATION_ARG, pre_command, cast_class=float)
            
            if duration is None:
                return

            timer = Timer(duration, callback_message)
            timer.start()
            await send_message("created and started timer {}".format(timer.get_id()))

        elif timer_action == Callback.CANCEL_PARAM:
            pre_command = "{} {}".format(Callback.TIMER_PARAM, Callback.CANCEL_PARAM)
            timer_id = await callback_helper.get_single_param(args, Callback.ID_ARG, pre_command)

            if timer_id is None:
                return
            
            timer: Timer = Timer.get_from_id(timer_id)
            if timer is None:
                await send_html("timer not found, call <code>{} {}</code> for all available Timers".format(TimerCallback.ACTION_NAME, Callback.GET_PARAM))
                return

            timer.cancel()
            await send_message("timer {} cancelled".format(timer.get_id()))
        
        else:
            await send_message("unknown parameter {}".format(timer_action))
